@@ -290,10 +290,15 @@ class BioformatsMetadata(PlateMetadata):
             else:
                 value = v_units.value(UNITS.MICROMETER).doubleValue()
             values.append(value)
+        values = tuple(values)
+        if not np.isclose(values[0], values[1], rtol=1e-4, atol=0):
+            raise Exception(f"Can't handle non-square pixels {values[::-1]}")
         if values[0] != values[1]:
-            raise Exception("Can't handle non-square pixels (%f, %f)"
-                            % tuple(values))
-        return values[0]
+            warn_data(
+                f"Pixel size is slightly non-square {values[::-1]}. Using"
+                f" {values[1]} for both dimensions."
+            )
+        return values[1]
 
     @property
     def pixel_dtype(self):
@@ -1264,7 +1269,6 @@ class TiffListWriter:
             for ci, channel in enumerate(mosaic.channels):
                 if self.verbose:
                     print(f"    Channel {channel}:")
-                img = mosaic.assemble_channel(channel)
                 path = self.path_format.format(cycle=mi, channel=channel)
                 # FIXME: We would ideally report this and exit immediately
                 # rather than warn after all the alignment has been done, but
@@ -1274,9 +1278,11 @@ class TiffListWriter:
                     warn_data(
                         f"Output path collision -- overwriting {path} (please"
                         " include both {cycle} and {channel} placeholders in"
-                        " the output path)"
+                        " the output path, or use the .ome.tif extension to"
+                        " write all channels to one file)"
                     )
                 used_paths.add(path)
+                img = mosaic.assemble_channel(channel)
                 with tifffile.TiffWriter(path, bigtiff=True) as tiff:
                     tiff.write(
                         data=img,
@@ -1289,7 +1295,12 @@ class TiffListWriter:
                 img = None
 
 
-class DataWarning(UserWarning):
+class Warning(UserWarning):
+    """Warnings about ashlar operation."""
+    pass
+
+
+class DataWarning(Warning):
     """Warnings about the content of user-provided image data."""
     pass
 
